==> shake_widget-0.0.1.tar.gz: lib/shake_widget.dart <==
library shake_widget;

import 'package:flutter/material.dart';
import 'package:vibration/vibration.dart';

/// A Calculator.
class ShakeWidget extends StatefulWidget {
  final Widget? child;
  Axis axisDirection;
  bool vibrate;
  Duration duration;

  ShakeWidget(
      {@required this.child,
      this.axisDirection = Axis.horizontal,
      this.duration = const Duration(milliseconds: 500),
      this.vibrate = false});

  @override
  State<StatefulWidget> createState() => _ShakeWidgetState();
}

class _ShakeWidgetState extends State<ShakeWidget>
    with SingleTickerProviderStateMixin {
  final TextEditingController textController = TextEditingController();
  AnimationController? controller;

  @override
  void initState() {
    controller = AnimationController(duration: widget.duration, vsync: this);
    super.initState();
  }

  EdgeInsets getAnimatedPadding(Animation<double> offsetAnimation) {
    if (widget.axisDirection == Axis.horizontal)
      return EdgeInsets.only(
          left: offsetAnimation.value + 24.0,
          right: 24.0 - offsetAnimation.value);
    else
      return EdgeInsets.only(
          top: offsetAnimation.value + 24.0,
          bottom: 24.0 - offsetAnimation.value);
  }

  vibrate() async {
    if (await Vibration.hasVibrator()) {
      Vibration.vibrate(duration: 500);
    }
  }

  @override
  Widget build(BuildContext context) {
    final Animation<double> offsetAnimation = Tween(begin: 0.0, end: 24.0)
        .chain(CurveTween(curve: Curves.elasticIn))
        .animate(controller!)
          ..addStatusListener((status) {
            if (status == AnimationStatus.completed) {
              controller!.reverse();
            }
          });

    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        AnimatedBuilder(
            animation: offsetAnimation,
            builder: (buildContext, child) {
              if (offsetAnimation.value < 0.0)
                print('${offsetAnimation.value + 8.0}');
              return Container(
                padding: getAnimatedPadding(offsetAnimation),
                child: widget.child,
              );
            }),
        RaisedButton(
          onPressed: () {
            if (textController.value.text.isEmpty || true)
              controller!.forward(from: 0.0);
            vibrate();
          },
          child: Text('Enter'),
        )
      ],
    );
  }
}

==> shake_widget-0.0.4.tar.gz: lib/shake_widget.dart <==
library shake_widget;

import 'package:flutter/material.dart';
import 'package:shake_widget/controller.dart';

class ShakeWidget extends StatefulWidget {
  final Widget? child;
  Axis axisDirection;
  bool vibrate;
  Duration duration;
  late ShakeController? shakeController;

  ShakeWidget(
      {@required this.child,
      this.axisDirection = Axis.horizontal,
      this.duration = const Duration(milliseconds: 500),
      @required this.shakeController,
      this.vibrate = false}):assert(shakeController!=null);

  @override
  State<StatefulWidget> createState() => _ShakeWidgetState();
}

class _ShakeWidgetState extends State<ShakeWidget>
    with SingleTickerProviderStateMixin {
  final TextEditingController textController = TextEditingController();

  @override
  void initState() {
   widget.shakeController!.controller = AnimationController(duration: widget.duration, vsync: this);
    super.initState();
  }

  EdgeInsets getAnimatedPadding(Animation<double> offsetAnimation) {
    if (widget.axisDirection == Axis.horizontal)
      return EdgeInsets.only(
          left: offsetAnimation.value + 24.0,
          right: 24.0 - offsetAnimation.value);
    else
      return EdgeInsets.only(
          top: offsetAnimation.value + 24.0,
          bottom: 24.0 - offsetAnimation.value);
  }



  @override
  Widget build(BuildContext context) {
    final Animation<double> offsetAnimation = Tween(begin: 0.0, end: 24.0)
        .chain(CurveTween(curve: Curves.elasticIn))
        .animate(widget.shakeController!.controller)
          ..addStatusListener((status) {
            if (status == AnimationStatus.completed) {
              widget.shakeController!.controller.reverse();
            }
          });

    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        AnimatedBuilder(
            animation: offsetAnimation,
            builder: (buildContext, child) {


              return Container(
                padding: getAnimatedPadding(offsetAnimation),
                child: widget.child,
              );
            }),
      ],
    );
  }
}
